﻿using Kivii.Third.Chinaerdos.Entities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.Third.Chinaerdos.Requests
{
    #region Request
    public class OrderResponse
    {
        public int code { get; set; }

        public string message { get; set; }

        public OrderResults data { get; set; }
    }

    public class OrderResults
    {
        public int recordsTotal { get; set; }
        public string resp_code { get; set; }
        public string message { get; set; }
        public string errors { get; set; }
        public List<ErdosOrder> results { get; set; }
    }

    /// <summary>
    /// 获取进行中的三方检测单据列表(包含单据基本信息和检测项信息)
    /// </summary>
    //[Route("/thirdapi/wtsapi/coord-wts/get-wts-list")]
    [Route(Configs.RouteGetWtsList)]
    public class ErdosOrderGetWtsList : IReturn<OrderResponse>
    {
        [ApiMember(Description = "客户分配L")]
        public string appToken { get; set; }

        public string signature { get; set; }

        public string timestamp { get; set; }

        [ApiMember(Description = "时间(从)可填")]
        public DateTime? beginTime { get; set; }

        [ApiMember(Description = "时间(到)可填")]
        public DateTime? endTime { get; set; }

        [ApiMember(Description = "返回记录数(可填，默认为10)")]
        public int length { get; set; }

        [ApiMember(Description = "记录偏移量(可填,默认为0)")]
        public int start { get; set; }
    }

    /// <summary>
    /// 获取指定单号的三方检测单据详情(包含单据基本信息和检测项信息)
    /// </summary>
    //[Route("/thirdapi/wtsapi/coord-wts/get-wts-data")]
    [Route(Configs.RouteGetWtsData)]
    public class ErdosOrderGetData : IReturn<OrderResponse>
    {
        [ApiMember(Description = "客户分配L")]
        public string appToken { get; set; }

        public string signature { get; set; }

        public string timestamp { get; set; }

        public string docNo { get; set; }
    }

    /// <summary>
    /// 确认接受三方检测单
    /// </summary>
    //[Route("/thirdapi/wtsapi/coord-wts/accept-wts")]
    [Route(Configs.RouteAcceptWts)]
    public class ErdosOrderAcceptConfirm : IReturn<OrderResponse>
    {
        [ApiMember(Description = "客户分配L")]
        public string appToken { get; set; }

        public string signature { get; set; }

        public string timestamp { get; set; }

        public string ORDER_NO { get; set; }
    }

    /// <summary>
    /// 更新三方检测结果
    /// </summary>
    //[Route("/thirdapi/wtsapi/coord-wts/update-wts-result")]
    [Route(Configs.RouteUpdateWtsResult)]
    public class ErdosOrderUploadResult : IReturn<OrderResponse>
    {
        [ApiMember(Description = "客户分配L")]
        public string appToken { get; set; }

        public string signature { get; set; }

        public string timestamp { get; set; }

        public OrderResult DATA { get; set; }
    }

    /// <summary>
    /// 根据URL地址更新三方检测报告
    /// </summary>
    //[Route("/thirdapi/wtsapi/coord-wts/update-wts-report")]
    [Route(Configs.RouteUpdateWtsReport)]
    public class ErdosOrderUploadPdf : IReturn<OrderResponse>
    {
        [ApiMember(Description = "客户分配L")]
        public string appToken { get; set; }

        public string signature { get; set; }

        public string timestamp { get; set; }

        public string ORDER_NO { get; set; }

        public List<OrderPdf> DATA { get; set; }
    }

    /// <summary>
    /// 确认完成检测
    /// </summary>
    //[Route("/thirdapi/wtsapi/coord-wts/close-wts")]
    [Route(Configs.RouteCloseWts)]
    public class ErdosOrderUploadComplete : IReturn<OrderResponse>
    {
        [ApiMember(Description = "客户分配L")]
        public string appToken { get; set; }

        public string signature { get; set; }

        public string timestamp { get; set; }

        public string ORDER_NO { get; set; }
    }
    #endregion
}
